@@ -421,6 +421,7 @@ class ContentQuantity(Content):
         if isinstance(arg, float):
             return cls.cv_signedness.convert(bit_size, round(arg / cls.cv_lsb))
         if isinstance(arg, tuple):
+            assert arg[1] == cls.cv_unit
             return cls.cv_signedness.convert(
                 bit_size, round(arg[0] / cls.cv_lsb))
         assert_never(arg)
@@ -576,6 +577,12 @@ class NonSpare:
     def _create(cls, arg: Any) -> Any:
         if isinstance(arg, cls):
             return arg
+        # first field of a tuple is maybe item name
+        if isinstance(arg, tuple):
+            if len(arg) == 2:
+                if isinstance(arg[0], str):
+                    name, arg = arg
+                    assert name == cls.cv_name
         val = cls.cv_rule.create(arg)  # type: ignore
         return cls(val)
 
@@ -689,8 +696,6 @@ class Group(Variation):
         items = []
         bs = Bits.from_uinteger(0, cls.cv_bit_offset8, 0)
         for ((a, size), b) in zip(cls.cv_items_list, arg):
-            if isinstance(b, tuple):
-                b = b[1]
             i = a.create(b)  # type: ignore
             items.append(i)
             bs += i.unparse()
@@ -778,8 +783,6 @@ class Extended(Variation):
                     bs += Bits.fx(fx)
                 else:
                     a, size = a  # type: ignore
-                    if isinstance(b, tuple):
-                        b = b[1]
                     i = a.create(b)  # type: ignore
                     items.append(i)  # type: ignore
                     bs += i.unparse()  # type: ignore
@@ -1309,23 +1312,18 @@ class UapMultiple(Uap):
         """
         lst = cls.cv_uaps.values()
 
-        def go(s: Bits) -> List[List[Any]]:
+        def go(acc: List[Any], s: Bits) -> Any:
             if not len(s):
-                return []
-            rv = []
+                yield acc
             for cls in lst:
                 result = cls._parse(s)
                 if isinstance(result, ValueError):
                     continue
                 x, remaining = result
-                xs = go(remaining)
-                if xs == []:
-                    rv.append([x])
-                else:
-                    for i in xs:
-                        rv.append([x] + i)
-            return rv
-        return go(bs)
+                for i in go(acc + [x], remaining):
+                    yield i
+
+        return list(go([], bs))
 
 
 class FspecType:
