@@ -306,6 +306,12 @@ def test_extended3() -> None:
     T = Cat_000_1_0.cv_record.spec('102')
     obj = T.create((1, 2))
     assert obj.unparse() == Bits.from_bytes(unhexlify('0304'))
+    obj = T.create(((1, None), (2, None)))
+    assert obj.unparse() == Bits.from_bytes(unhexlify('0304'))
+    obj = T.create(((1, None), ((0, 0, 2), None)))
+    assert obj.unparse() == Bits.from_bytes(unhexlify('0304'))
+    obj = T.create(((1, None), ((('SG1', 0), 0, 2), None)))
+    assert obj.unparse() == Bits.from_bytes(unhexlify('0304'))
 
 
 def test_repetitive1() -> None:
@@ -832,3 +838,19 @@ def test_parse4() -> None:
         result2 = Cat1.cv_uap.parse('track', bs2)
         assert not isinstance(result2, ValueError)
         assert len(result2) == 3
+
+def test_parse5() -> None:
+    """Non-compatible items in multiple uaps."""
+    Cat1 = Cat_001_1_0
+    rec_plot = Cat1.cv_uap.spec('plot').create({'041': 0xff})
+    rec_track = Cat1.cv_uap.spec('track').create({'042': 0xffff})
+
+    bs_plot = rec_plot.unparse()
+    bs_track = rec_track.unparse()
+
+    results_plot = Cat1.cv_uap.parse_any_uap(bs_plot)
+    assert len(results_plot) == 1
+
+    results_track = Cat1.cv_uap.parse_any_uap(bs_track)
+    assert len(results_track) == 1
+
